#  -----------
# |>Ca  @ S wC|
#  -----------

level.description("Time to hone your skills and apply all of the abilities that you have learned.")
level.tip("Watch your back.")
level.clue("Don't just keep shooting the bow while you are being attacked from behind.")

level.time_bonus(40)
level.ace_score(100)
level.size(11, 1)
level.stairs(0, 0)

level.warrior(5, 0, 'east')

level.unit('captive', 1, 0, 'east')
level.unit('archer', 2, 0, 'east')
level.unit('thick_sludge', 7, 0, 'west')
level.unit('wizard', 9, 0, 'west')
level.unit('captive', 10, 0, 'west')
